<?php if (!defined('PmWiki')) exit();

/**------------------------------------------------------------------------
    BridgeSite.php   
    Original content Copyright 2022 Kirk Siqveland (Kirk@CyberTamer.com)

    -This is a Code branch of includeSite.php - see Original Copyright below.

    BridgeSite allows the inclusion of non-pmwiki pages as content within a
    PMWiki page using iFrames - allowing integration of features that might 
    be difficult to execute from within the PMWiki environment.

    For Dynamicaly Sizing & Responsive iframes see
    "iFrame reSizer" features on the 
    https://www.pmwiki.org/wiki/Cookbook/BridgeSite page


    This file is distributed under the terms of the GNU General Public 
    License as published by the Free Software Foundation; either 
    version 2 of the License.       

    USAGE:

    As a stand-alone solution: 

    >> You need a copy of the BridgeSite.php file in your {pmwiki}/cookbook directory
    >> you will also need the following lines into your {pmwiki}/local/config.php file:
        ## Include Code for BridgeSite - iFrame insertion tool recipe
            include_once ('cookbook/BridgeSite.php') ;


    As a Dynamic-Sizing solution: 
    (Most Browsers require the embedded page to be in the same domain )

    >> You need a copy of the BridgeSite.php file in your {pmwiki}/cookbook directory
    >> both iframe_host.js and iframe_guest.js need to be in the {pmwiki}/pub directory
    >> you will also need the following lines into your {pmwiki}/local/config.php file:

        ## Include Code for BridgeSite - iFrame insertion tool recipe
            include_once ('cookbook/BridgeSite.php') ;
        ## Insert the iframe_host.js script to the bottom of your Skin template.
            $HTMLFooterFmt['BridgeSite'] = '<script src="$FarmPubDirUrl/iframe_host.js"></script>' ;

    >> See https://www.pmwiki.org/wiki/Cookbook/BridgeSite   

  Simple pmwiki Markup would be something like
  (:BridgeSite http://SomeURL.com:)

  or for something dynamic:
    (:BridgeSite https://www.mydomain.org/media/dplayer/dPlayer.php?audiopath=/media/MixTapeII style="border:none; background-color: transparent;" :)
    
  I use something much like that for my dynamic HTML5 folder-player on several PMWiki sites.

-------------------------------------------------------------------------**/


/**
NB!  This requires several parts: 
- BridgeSite.php (This file )  copied to the /CookBook directory
- iframe_host.js               copied to the /pub directory
- iframe_guest.js              copied to the /pub directory

You must also add the following lines to your {pmwiki}/local/Config.php file

  ## Include Code for BridgeSite - iFrame insertion tool recipe
    include_once ('cookbook/BridgeSite.php') ;
  ## This will insert the iframe_host.js script to the bottom of your Skin template.
    $HTMLFooterFmt['BridgeSite'] = '<script src="$FarmPubDirUrl/iframe_host.js"></script>' ;

**/


SDV($RecipeInfo['BridgeSite']['Version'], '2021-12-18');
$FmtPV['$BridgeSiteVersion'] = "'{$RecipeInfo["BridgeSite"]["Version"]}'";

## Usage -
## Just enter the Markup name followed by the URL.
## If you want to communicate with the hosted page it will need to be
## within the same domain as your wiki, but outside of the wiki directory.
## e.g.:  

// (:BridgeSite https://www.myexampledomain.org/myfunctions/index.php :)
## Or you can add an element id-name and/or an element style(s):

// (:BridgeSite https://www.myexampledomain.org/myfunctions/login.php id="frame1" style="width:98%;" :)
##   Note: setting a CSS Style here over-rides other style sources!


## -- Here's the Core Function:
$BridgeTally = 0 ;

function SiteBridge($m) {  
global $BridgeTally ;
  ## $m -> an array with the parameters matches
  ## $m[0] -> the whole match, everything between  '(:BridgeSite'  and  ':)'
  ## $m[1] -> subgroup 1 : the url
  ## $m[2] -> subgroup 2 : the parameters

## peel off ?_GET vars already included in the address
  if($peg = stripos($m[1], '?')){
    $basePath = substr($m[1], 0, $peg) ;
    $gotParams = '&'.substr($m[1], $peg+1)   ;
  }else{
    $basePath = $m[1] ;
  }

  $strParam = $m[2] ;



  // parse the parameters: options id, class, style, and 'get' params, otherwise ignore
    $pattern = '/(id|class|style|getvar)=((\\d+)|(["\'])(.*?)\4)/'; 
    $results = preg_match_all($pattern,$strParam,$match,PREG_SET_ORDER);

    $bridge_params = "" ;

      foreach ($match as $part) {
        ##  $part[0] = the whole line quotes and all
        ##  $part[1] = the matching tag
        ##  $part[5] = the string after the equal sign, no quotes.
  
        switch (trim(strtolower($part[1]))) {
            case 'id':        # id
              $id      = " id="       ;
              $id     .= $part[5]     ;
              //$id     .= "\""         ;
              $bridge_params .= $id  ;
              break;

            case 'class':        # class
              $class_params .= $part[5] ;
              break;     

            case 'style':        # style
              $style  = " style=\"" ;
              $style .= $part[5]        ;
              $style .= "\""            ;
              $bridge_params .= $style  ;
              break;

            case 'getvar':        # [Get]
              $getvar .= '&'.trim($part[5]) ;     
              break;  
        }
      }

####  the HOSTSID section here is used to synchronize the Session ID for both documents
  ##  This was added for the MyDBLogin recipe to coordinate pmwiki login features.
  ##  The Session ID is passed from the Host to the Guest which must then self-assign the ID

  ## $HOSTSID Adds the Session ID as a GET to the address, so the two windows can pass messages.
  ## This is an essential part of the MyDBLogin Recipe, but not otherwise necessary.
  ## Comment out for cleaner URLs

        $URLExtra  = "?"     ;
        $HOSTSID   = "SSID=" ;
        $HOSTSID  .= openssl_encrypt(session_id(), "AES-128-ECB", "YourSecretKey");
      $URLExtra .= $HOSTSID.$gotParams.$getvar.' ';
####      

  ## In case we have multiple Bridged-Sites each needs a unique ID
    $BridgeTally++;
    $BridgeID = $BridgeTally - 1 ;

  ## Lets put it all together:
    $Output =  "<!-- Bridged_Site: -->";
    $Output .= "<iframe id=$BridgeID class=\"BridgeFrame $class_params\" " . $bridge_params . "  src=\"" . Keep($basePath).Keep($URLExtra)."\"></iframe>";
    $Output .= "<!-- /Bridged_Site -->";

  return $Output;

} // end of function SiteBridge($m)  


## With all that in place, we can now build the Markup:
#### fit for PHP5.5 and higher (tested on PHP7.x)

##  This allows the use of (:BridgeSite http://SomeURL.com:) from PMWiki Edit mode.
  $BSpattern = "/\\(:BridgeSite\\s+(https?:[^$UrlExcludeChars]*?)\\s+(.*):\\)/";

Markup('BridgeSite', 'inline', $BSpattern, "SiteBridge");



##---------------------------------------------------------------------------------
##---------------------------------------------------------------------------------

## >>> COPYRIGHT NOTICE FOR THE ORIGINAL INCLUDESITE RECIPE:

/*  Copyright 2004 Patrick R. Michaud (pmichaud@pobox.com)
    This file is distributed under the terms of the GNU General Public 
    License as published by the Free Software Foundation; either 
    version 2 of the License, or (at your option) any later version.  
/*---------------------------------------------------------------

  * Copyright *
  This PmWiki addon was written on March 20, 2004 by Steven Leite
  (steven_leite@kitimat.net).  The same terms and conditions that
  apply to PmWiki also apply to this script.
  
  Update: 
  I have modified the file on march 25, 2019 due to
  the needs of PHP_7.2 and HTML5.
  
  * Special Thanks *
  Thanks to Pm (Patrick Michaud, www.pmichaud.com), for creating
  PmWiki, and for sharing his knowledge and insightfulness which
  is what made this script possible.

  * Description *
  This add-on allows a PmWiki user to include the contents of any
  external webpage into their WikiPage.

  * Features *
  The script won't overwrite any existing configuration date in
  your PmWiki install.

  ...

*/
